@@ -1,13 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelSQL, ModelView, MatchMixin, fields
+from trytond.model import (
+    ModelSQL, ModelView, MatchMixin, sequence_ordered, fields)
 from trytond.pool import PoolMeta
 from trytond.pyson import Eval
 
-__all__ = ['CredentialUPS', 'Carrier']
 
-
-class CredentialUPS(ModelSQL, ModelView, MatchMixin):
+class CredentialUPS(sequence_ordered(), ModelSQL, ModelView, MatchMixin):
     'UPS Credential'
     __name__ = 'carrier.credential.ups'
 
